#
# spec file for package prewikka
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           prewikka
Version:        5.1.1
Release:        bp153.1.15
Summary:        Graphical front-end analysis console for the Prelude Framework
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Frontends
Url:            https://www.prelude-siem.org
Source0:        https://www.prelude-siem.org/pkg/src/5.1.0/%{name}-%{version}.tar.gz
Patch0:         prewikka-fix_shebang.patch
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  python3-Babel
BuildRequires:  python3-devel
BuildRequires:  python3-lesscpy
BuildRequires:  python3-rpm-macros
BuildRequires:  python3-setuptools
Requires:       prewikka-lang >= %{version}
Requires:       python3-Babel
Requires:       python3-Mako
Requires:       python3-PyYAML
Requires:       python3-Werkzeug
Requires:       python3-croniter
Requires:       python3-gevent
Requires:       python3-lark-parser
Requires:       python3-libprelude
Requires:       python3-libpreludedb
Requires:       python3-python-dateutil
Requires:       python3-pytz
Requires:       python3-voluptuous
Requires:       xorg-x11-fonts
BuildArch:      noarch
Obsoletes:      prewikka-core < %{version}-%{release}
Provides:       prewikka-core = %{version}-%{release}

%python_subpackages

%description
Prewikka is the graphical front-end analysis console for the Prelude
Universal SIM. Prewikka provides alert aggregation and sensor and
hearbeat views, and has user management and configurable filters, as
well as access to external tools such as whois and traceroute.

%package lang
Summary:        Prewikka lang files
Group:          Productivity/Networking/Web/Frontends

%description lang
Lang files for prewikka.

%prep
%setup -q
%patch0

%build

%install
python3 setup.py install -O1 --force --root %{buildroot}
%fdupes %{buildroot}%{$python3_sitelib}/prewikka

install -d -m 0755 %{buildroot}%{_datadir}/locale
cp -r %{buildroot}%{python3_sitelib}/%{name}/locale/* %{buildroot}%{_datadir}/locale/
rm -rf %{buildroot}%{python3_sitelib}/%{name}/locale
ln -s %{_datadir}/locale %{buildroot}%{python3_sitelib}/%{name}/locale

mkdir -p %{buildroot}%{_defaultdocdir}/%{name}-%{version}

find %{buildroot} -name __pycache__ -exec rm -rfv {} +

%find_lang %{name}

%files -n python3-%{name}
%defattr(-, root, root, -)
%attr(0750, -,-) %dir %{_sysconfdir}/%{name}/
%config(noreplace) %attr(0640, -,-) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %attr(0640, -,-) %{_sysconfdir}/%{name}/menu.yml
%{_datadir}/%{name}
%doc COPYING* AUTHORS README NEWS HACKING.README
%{python3_sitelib}/prewikka/
%{python3_sitelib}/prewikka*.egg-info
%{_bindir}/prewikka-httpd
%{_bindir}/prewikka-cli
%{_bindir}/prewikka-crontab

%files -n %{name}-lang -f %{name}.lang

%changelog
* Fri Oct 25 2019 thomas.andrejak@gmail.com
  Bump version 5.1.1
  - Use the correct hook in heartbeat detail
  - Fix grouping errors with datasearch:update
  - Reload plugins if needed in prewikka-crontab
- Add missing depends (see INSTALL file):
  - python3-croniter
  - python3-gevent
  - python3-voluptuous
  - python3-lark-parser
* Fri Oct 25 2019 thomas.andrejak@gmail.com
  Bump version 5.1.0
  - Update frameworks
  - Add prewikka-cli, prewikka in command line
  - Add new options in config file
  - Various fixes
  - Separate dataprovider backend and instance
  - Implement support for time-spanning data
  - Add past periods to the control menu
  - Add comparison operators for additional data
- Use the correct hook in heartbeat detail
- Remove patchs:
  - prewikka-fix_python3.patch
  - Fixed upstream
- Add patchs:
  - prewikka-fix_shebang.patch
  - Non executives files do not need shebang
- Remove python2
  - Python 2 will be removed step by step in all Linux distributions
* Sat Feb 10 2018 thomas.andrejak@gmail.com
- Fix building prewikka with new find-lang.sh
* Wed Oct  4 2017 thomas.andrejak@gmail.com
- Update to 4.0.0
- Create python2-prewikka and python3-prewikka
  packages since prewikka is python 3 compatible
- Move to Python Singlespec
- Remove patch prewikka-ez_setup.patch because we can only be
  compatible with Factory/Tumbleweed because of Python Singlespec
- Add patch prewikka-fix_python3.patch to make prewikka fully
  compatible with Python 3
* Fri Feb 10 2017 thomas.andrejak@gmail.com
- Update to 3.1.0 (Prelude 3.1.0 released on 14 Sept 2016)
- Remove unnecessary patches
  - prewikka-cheetah-shbang.patch
  - prewikka-wsgi-shbang.patch
- Spec-Cleaner
* Thu Jan 26 2017 jengelh@inai.de
- Trim filler words from description.
- Replace -exec rm by simpler -delete.
* Sun Sep  4 2016 thomas.andrejak@gmail.com
  Fix Group to be a valid OpenSuse Group
  Fix Requires
  Fix source URL
  Fix dependencies
  Clean usage of "-n %%{name}-"
* Tue May  3 2016 thomas.andrejak@gmail.com
  Initial import
  Add patchs :
  * prewikka-cheetah-shbang.patch
  * Fix shebang in cheetah generated files
  * prewikka-ez_setup.patch
  * Support old setuptools
  * prewikka-wsgi-shbang.patch
  * Fix shebang in wsgi file
